@@ -18,7 +18,7 @@
  *  - graph_height
  *  - bar_gap
  *
- *  - graphs [ {id, name, title} ]
+ *  - graphs [ {id, name, title, bar_secs} ]
  *  - graphs_uri
  *
  *  - window.onload = graph_loader
@@ -85,7 +85,7 @@ function poll() {
   for (var i=0; i<graphs.length; i++)
   {
    g = xh.responseXML.getElementsByTagName(graphs[i].name);
-   buildGraph(graphs[i].graph, graphs[i].title,
+   buildGraph(graphs[i].graph, graphs[i].title, graphs[i].bar_secs,
     g[0].getElementsByTagName("e"));
   }
   document.getElementById("graph_reload").innerHTML = "reload graphs";
@@ -112,7 +112,13 @@ function addBar(graph, title, barclass, width, height, left, bottom) {
  graph.appendChild(bar);
 }
 
-function buildGraph(graph, title, elems) {
+function kbps(bps) {
+   bps /= 1024;
+   if (bps < 1) return bps.toPrecision(2);
+   else return bps.toFixed(1);
+}
+
+function buildGraph(graph, title, bar_secs, elems) {
  var total_max = 0;
  var data = []; /* list of [in, out] */
  for (var i=0; i<elems.length; i++) {
@@ -153,8 +159,11 @@ function buildGraph(graph, title, elems) {
   var h_i = Math.round( b_i * graph_height / total_max );
   var h_o = Math.round( b_o * graph_height / total_max );
 
-  var label = b_p+": "+thousands(b_i)+" bytes in, "+
-   thousands(b_o)+" bytes out";
+  var label = b_p+": "+
+   thousands(b_i)+" bytes in, "+
+   thousands(b_o)+" bytes out | "+
+   kbps(b_i/bar_secs)+" KB/s in, "+
+   kbps(b_o/bar_secs)+" KB/s out";
   addBar(igraph, label, "bar_in", curr_w, h_i, xofs, 0);
   addBar(igraph, label, "bar_out", curr_w, h_o, xofs, h_i);
  }
